Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/tyora/__init__.py | (no function) | 0 | 0 | 0 | 100%
src/tyora/session.py | MoocfiCsesSession.__init__ | 7 | 0 | 0 | 100%
src/tyora/session.py | MoocfiCsesSession.is_logged_in | 5 | 0 | 0 | 100%
src/tyora/session.py | MoocfiCsesSession.login | 22 | 4 | 0 | 82%
src/tyora/session.py | find_link | 7 | 1 | 0 | 86%
src/tyora/session.py | parse_form | 9 | 0 | 0 | 100%
src/tyora/session.py | (no function) | 21 | 2 | 0 | 90%
src/tyora/tyora.py | parse_args | 22 | 2 | 0 | 91%
src/tyora/tyora.py | create_config | 4 | 4 | 0 | 0%
src/tyora/tyora.py | write_config | 6 | 6 | 0 | 0%
src/tyora/tyora.py | read_config | 7 | 7 | 0 | 0%
src/tyora/tyora.py | read_cookie_file | 6 | 6 | 0 | 0%
src/tyora/tyora.py | write_cookie_file | 2 | 2 | 0 | 0%
src/tyora/tyora.py | find_link | 6 | 0 | 0 | 100%
src/tyora/tyora.py | parse_form | 9 | 9 | 0 | 0%
src/tyora/tyora.py | parse_task_list | 19 | 19 | 0 | 0%
src/tyora/tyora.py | print_task_list | 7 | 7 | 0 | 0%
src/tyora/tyora.py | parse_task | 21 | 21 | 0 | 0%
src/tyora/tyora.py | print_task | 3 | 3 | 0 | 0%
src/tyora/tyora.py | parse_submit_result | 8 | 8 | 0 | 0%
src/tyora/tyora.py | main | 67 | 67 | 0 | 0%
src/tyora/tyora.py | (no function) | 54 | 3 | 0 | 94%
tests/__init__.py | (no function) | 0 | 0 | 0 | 100%
tests/test_session.py | mock_session | 1 | 0 | 0 | 100%
tests/test_session.py | test_login_successful | 5 | 0 | 0 | 100%
tests/test_session.py | test_login_failed | 6 | 0 | 0 | 100%
tests/test_session.py | test_loading_cookies | 1 | 0 | 0 | 100%
tests/test_session.py | (no function) | 9 | 0 | 0 | 100%
tests/test_tyora.py | test_parse_args_missing_args | 2 | 0 | 0 | 100%
tests/test_tyora.py | test_parse_args_command | 2 | 0 | 0 | 100%
tests/test_tyora.py | TestFindLink.test_find_link_success | 1 | 0 | 0 | 100%
tests/test_tyora.py | TestFindLink.test_find_link_bad_xpath | 1 | 0 | 0 | 100%
tests/test_tyora.py | TestFindLink.test_find_link_bad_html | 1 | 0 | 0 | 100%
tests/test_tyora.py | test_create_config | 1 | 0 | 0 | 100%
tests/test_tyora.py | test_write_config | 1 | 0 | 0 | 100%
tests/test_tyora.py | test_read_config | 1 | 0 | 0 | 100%
tests/test_tyora.py | test_get_cookiejar | 1 | 0 | 0 | 100%
tests/test_tyora.py | (no function) | 17 | 0 | 0 | 100%
Total |  | 362 | 171 | 0 | 53%

No items found using the specified filter.